<?php

namespace WPScan;

# Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

class Summary
{
    /**
     * Class constructer.
     * 
     * @since 1.0.0
     * @access public
     * @return void
     */
    public function __construct($parent)
    {
        $this->parent = $parent;

        add_action('admin_init', [$this, 'add_meta_box_summary']);
        add_action('wp_ajax_wpscan_check_now', [$this, 'ajax_check_now']);
        add_action('wp_ajax_' . $this->parent->WPSCAN_TRANSIENT_CRON, [$this, 'ajax_doing_cron']);    
    }

    /**
     * Add meta box
     * 
     * @since 1.0.0
     * @access public
     * @return void
     */
    public function add_meta_box_summary()
    {
        $report = $this->parent->get_report();

        if ( empty($report) ) {
            return;
        }

        add_meta_box(
            'wpscan-metabox-summary',
            __('Summary', 'wpscan'),
            [$this, 'do_meta_box_summary'],
            'wpscan',
            'side',
            'high'
        );
    }

    /**
     * Redner meta box
     * 
     * @since 1.0.0
     * @access public
     * @return string
     */
    public function do_meta_box_summary()
    {
        $report = $this->parent->get_report();
        $errors = get_option($this->parent->OPT_ERRORS);
        $total = $this->parent->get_total_not_ignored();
        ?>

        <p>
            <?php _e('The last request to the', 'wpscan') ?>
            <a href="https://wpscan.com/" target="_blank"><?php _e( 'WPScan Vulnerability Database', 'wpscan' ) ?></a>
            <?php _e( 'was:', 'wpscan' ) ?> 
        </p>

        <p>
            <span class="dashicons dashicons-calendar-alt"></span>
            <strong><?php echo date_i18n( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), $report['cache'] ) ?></strong>
        </p>

        <?php
            if ( ! empty($errors) ) {
                foreach( $errors as $err ) {
                    // $err should not contain user input. If you like to add an esc_html() here, be sure to update the error text that use HTML
                    echo '<p class="wpscan-summary-res is-red"><span class="dashicons dashicons-megaphone"></span> <strong>' . $err . '</strong></p>';
                }
            } elseif ( empty($errors) && $total == 0 ) {
                echo '<p class="wpscan-summary-res is-green"><span class="dashicons dashicons-awards"></span> <strong>' . __( 'No known vulnerabilities found', 'wpscan' ) . '</strong></p>';
            } elseif( ! get_option($this->parent->OPT_API_TOKEN) ) {
                echo '<p class="wpscan-summary-res is-red"><span class="dashicons dashicons-megaphone"></span> <strong>' . __( 'You need to add a WPScan API Token to the settings page', 'wpscan' ) . '</strong></p>';
            } else {
                echo '<p class="wpscan-summary-res is-red"><span class="dashicons dashicons-megaphone"></span> <strong>' . __( 'Some vulnerabilities were found', 'wpscan' ) . '</strong></p>';
            }
        ?>

        <p class="description">
            <?php _e( 'Click the Run All button to run a vulnerability scan against your WordPress version, installed plugins and themes.', 'wpscan' ) ?>
        </p>

        <?php if ( get_option($this->parent->OPT_API_TOKEN) ) : ?>
            <p class="check-now">
                <span class="spinner"></span>
                <button type="button" class="button button-primary"><?php _e( 'Run All', 'wpscan' ) ?></button>
            </p>
        <?php endif ?>

        <?php
    }

    /**
     * Ajax check now
     * 
     * @since 1.0.0
     * @access public
     * @return void
     */
    public function ajax_check_now()
    {
        check_ajax_referer('wpscan');

        if ( ! current_user_can($this->parent->WPSCAN_ROLE) ) {
            wp_redirect(home_url());
            wp_die();
        }

        $this->parent->check_now();

        wp_die();
    }

    /**
     * Ajax to check when the cron task has finished
     * 
     * @since 1.0.0
     * @access public
     * @return void
     */
    public function ajax_doing_cron()
    {
        check_ajax_referer('wpscan');

        if ( ! current_user_can($this->parent->WPSCAN_ROLE) ) {
            wp_redirect(home_url());
            wp_die();
        }

        echo get_transient( $this->parent->WPSCAN_TRANSIENT_CRON ) ? 'YES' : 'NO';

        wp_die();
    }
}