<?php

/**
 * Classname: WPScan\Checks\xmlrpcEnabled
 */

namespace WPScan\Checks;

# Exit if accessed directly.
defined( 'ABSPATH' ) || exit;


class xmlrpcEnabled extends Check
{
    /**
     * Title.
     * 
     * @since 1.0.0
     * @access public
     * @return string
     */
    public function title()
    {
        return __('XML-RPC Enabled', 'wpscan');
    }

    /**
     * Description.
     * 
     * @since 1.0.0
     * @access public
     * @return string
     */
    public function description()
    {
        return __('Check if the WordPress XML-RPC is enabled.', 'wpscan');
    }

    /**
     * Success message.
     * 
     * @since 1.0.0
     * @access public
     * @return string
     */
    public function success_message()
    {
        return __('XML-RPC was found to be disabled.', 'wpscan');
    }

    /**
     * Perform the check and save the results.
     * 
     * @since 1.0.0
     * @access public
     * @return void
     */
    public function perform()
    {
        $vulnerabilities = $this->get_vulnerabilities();

        $url          = get_site_url() . '/xmlrpc.php';
        $request_body = '<?xml version="1.0" encoding="iso-8859-1"?><methodCall><methodName>demo.sayHello</methodName><params><param></param></params></methodCall>';
        $response     = wp_remote_post( $url, array( 'body' => $request_body ) );

        if (preg_match('/<string>Hello!<\/string>/', $response['body'])) {
          $this->add_vulnerability(__('The XML-RPC interface is enabled. This significantly increases your site\'s attack surface.', 'wpscan'), 'medium', sanitize_title($url));
        }
        
    }
}
